@@ -1,5 +1,8 @@
 package Zonemaster::LDNS::RR::NSEC3PARAM;
 
+use strict;
+use warnings;
+
 use parent 'Zonemaster::LDNS::RR';
 
 1;
@@ -30,6 +33,6 @@ Returns the iteration count.
 
 =item salt()
 
-Returns the cryptographic salt in binary form.
+Returns the contents of the salt field as a binary string, if non-empty; otherwise, returns an empty string.
 
 =back
